@@ -14,7 +14,7 @@ test_site = function(theme) {
 assert('new_site() and build_site() work with selected themes', {
   themes = c(
     'hugo-apero/hugo-apero',
-    sprintf('wowchemy/starter-hugo-%s', c('academic', 'online-course', 'research-group')),
+    sprintf('HugoBlox/theme-%s', c('online-course', 'research-group')),
     sprintf('yihui/hugo-%s', c('lithium', 'prose', 'xmag', 'xmin', 'ivy', 'paged'))
   )
   status = !sapply(themes, test_site)
